
#ifndef KPIMKDAV2_EXPORT_H
#define KPIMKDAV2_EXPORT_H

#ifdef KPIMKDAV2_STATIC_DEFINE
#  define KPIMKDAV2_EXPORT
#  define KPIMKDAV2_NO_EXPORT
#else
#  ifndef KPIMKDAV2_EXPORT
#    ifdef KPimKDAV2_EXPORTS
        /* We are building this library */
#      define KPIMKDAV2_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KPIMKDAV2_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KPIMKDAV2_NO_EXPORT
#    define KPIMKDAV2_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KPIMKDAV2_DEPRECATED
#  define KPIMKDAV2_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KPIMKDAV2_DEPRECATED_EXPORT
#  define KPIMKDAV2_DEPRECATED_EXPORT KPIMKDAV2_EXPORT KPIMKDAV2_DEPRECATED
#endif

#ifndef KPIMKDAV2_DEPRECATED_NO_EXPORT
#  define KPIMKDAV2_DEPRECATED_NO_EXPORT KPIMKDAV2_NO_EXPORT KPIMKDAV2_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KPIMKDAV2_NO_DEPRECATED
#    define KPIMKDAV2_NO_DEPRECATED
#  endif
#endif

#endif /* KPIMKDAV2_EXPORT_H */
